==> gemforged-3.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/item/GemforgedItems.java <==
package net.trique.gemforged.item;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1792;
import net.minecraft.class_1814;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;
import net.trique.gemforged.item.gear.*;

public class GemforgedItems {
    public static final class_1792 SHADOWSTEP_DAGGER = registerItem("shadowstep_dagger",
            new ShadowstepDaggerItem(new FabricItemSettings().method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 BATTLE_CHARM = registerItem("battle_charm",
            new BattleCharmItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 SANDBURST_STAFF = registerItem("sandburst_staff",
            new SandburstStaffItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 VENOMFANG_BLADE = registerItem("venomfang_blade",
            new VenomfangBladeItem(new FabricItemSettings().method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 PHOENIX_CHARM = registerItem("phoenix_charm",
            new PhoenixCharmItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 THUNDER_PRISM = registerItem("thunder_prism",
            new ThunderPrismItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904).method_24359()));
    public static final class_1792 GRAVITY_HORN = registerItem("gravity_horn",
            new GravityHornItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 VERDANT_TOTEM = registerItem("verdant_totem",
            new VerdantTotemItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));

    public static final class_1792 NYXITE = registerItem("nyxite",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 BLOODSTONE = registerItem("bloodstone",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 SOLARIUM = registerItem("solarium",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 VENOMYTE = registerItem("venomyte",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 PHOENIXTONE = registerItem("phoenixtone",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 PRISMYTE = registerItem("prismyte",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 GRAVITIUM = registerItem("gravitium",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 VERDANTITE = registerItem("verdantite",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));

    public static final class_1792 DAGGER_TEMPLATE = registerItem("dagger_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 CHARM_TEMPLATE = registerItem("charm_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 STAFF_TEMPLATE = registerItem("staff_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 PRISM_TEMPLATE = registerItem("prism_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 BLADE_TEMPLATE = registerItem("blade_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 HORN_TEMPLATE = registerItem("horn_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 TOTEM_TEMPLATE = registerItem("totem_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));

    private static class_1792 registerItem(String name, class_1792 item) {
        return class_2378.method_10230(class_7923.field_41178, new class_2960(Gemforged.MOD_ID, name), item);
    }

    public static void registerItems() {
        Gemforged.LOGGER.info("Registering Gemforged items");
    }
}

==> gemforged-4.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/item/GemforgedItems.java <==
package net.trique.gemforged.item;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1792;
import net.minecraft.class_1814;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;
import net.trique.gemforged.item.gear.*;

public class GemforgedItems {
    public static final class_1792 SHADOWSTEP_DAGGER = registerItem("shadowstep_dagger",
            new ShadowstepDaggerItem(new FabricItemSettings().method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 BATTLE_CHARM = registerItem("battle_charm",
            new BattleCharmItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 SANDBURST_STAFF = registerItem("sandburst_staff",
            new SandburstStaffItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 VENOMFANG_BLADE = registerItem("venomfang_blade",
            new VenomfangBladeItem(new FabricItemSettings().method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 PHOENIX_CHARM = registerItem("phoenix_charm",
            new PhoenixCharmItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 THUNDER_PRISM = registerItem("thunder_prism",
            new ThunderPrismItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904).method_24359()));
    public static final class_1792 GRAVITY_HORN = registerItem("gravity_horn",
            new GravityHornItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 VERDANT_TOTEM = registerItem("verdant_totem",
            new VerdantTotemItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904)));
    public static final class_1792 GHOST_BOW = registerItem("ghost_bow",
            new GhostBowItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 PHOENIXFIRE_STAFF = registerItem("phoenixfire_staff",
            new PhoenixfireStaffItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904).method_7895(240)));
    public static final class_1792 GLACIAL_CHARM = registerItem("glacial_charm",
            new GlacialCharmItem(new FabricItemSettings().method_7889(1).method_7894(class_1814.field_8904).method_7895(240)));

    public static final class_1792 NYXITE = registerItem("nyxite",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 BLOODSTONE = registerItem("bloodstone",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 SOLARIUM = registerItem("solarium",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 VENOMYTE = registerItem("venomyte",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 PHOENIXTONE = registerItem("phoenixtone",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 PRISMYTE = registerItem("prismyte",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 GRAVITIUM = registerItem("gravitium",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));
    public static final class_1792 VERDANTITE = registerItem("verdantite",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907)));

    public static final class_1792 DAGGER_TEMPLATE = registerItem("dagger_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 CHARM_TEMPLATE = registerItem("charm_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 STAFF_TEMPLATE = registerItem("staff_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 PRISM_TEMPLATE = registerItem("prism_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 BLADE_TEMPLATE = registerItem("blade_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 HORN_TEMPLATE = registerItem("horn_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 TOTEM_TEMPLATE = registerItem("totem_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));
    public static final class_1792 BOW_TEMPLATE = registerItem("bow_template",
            new class_1792(new FabricItemSettings().method_7894(class_1814.field_8907).method_7889(1)));

    private static class_1792 registerItem(String name, class_1792 item) {
        return class_2378.method_10230(class_7923.field_41178, new class_2960(Gemforged.MOD_ID, name), item);
    }

    public static void registerItems() {
        Gemforged.LOGGER.info("Registering Gemforged items");
    }
}
